Manufacturer - Nautobot Documentation

Skip to content

# Manufacturers

A manufacturer represents the "maker" of a device or module; e.g. Cisco or Dell. Each device type and module type must be assigned to a manufacturer. (Inventory items and platforms may also be associated with manufacturers.) Each manufacturer must have a unique name and may have a description assigned to it.

Tip

Manufacturers are also the recommended way to represent cloud providers that your cloud accounts and your cloud resource types belong to.